<?php
namespace ElementorClever\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * @since 1.1.0
 */
class Clever extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
    return 'Clever_Radio_Player';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
    return esc_html__( 'Clever Radio Player', 'elementor-clever' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
    return 'eicon-play';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.1.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
    return [ 'lambert-widgets' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function register_controls() {
    //general controls (ex content)
    $this->start_controls_section(
      'general_content',
      [
        'label' => esc_html__( 'General', 'elementor-clever' ),
      ]
    );

    $this->add_control(
      'radio_stream',
      [
        'label' => esc_html__( 'Radio Stream Link', 'elementor-clever' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );

    $this->add_control(
      'optional_shoutcast_sid',
      [
        'label' => esc_html__( 'Optional Shoutcast Sid', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 100,
				'step' => 1,
				'default' => 1,
      ]
    );

    $this->add_control(
      'playerWidth',
      [
        'label' => esc_html__( 'Player Width', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 50,
        'max' => 10000,
        'step' => 1,
        'default' => 760,
      ]
    );


    $this->add_control(
			'width100Proc',
			[
				'label' => esc_html__( 'Player Width 100%', 'elementor-clever' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-clever' ),
				'label_off' => esc_html__( 'No', 'elementor-clever' ),
				'return_value' => 'true',
				'default' => 'false',
			]
		);

    $this->add_control(
      'historyLeftPadding',
      [
        'label' => esc_html__( 'Player Left Padding', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 550,
				'step' => 1,
				'default' => 25,
      ]
    );

    $this->add_control(
      'historyRightPadding',
      [
        'label' => esc_html__( 'Player Right Padding', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 550,
				'step' => 1,
				'default' => 25,
      ]
    );

    $this->add_control(
      'historyTopPadding',
      [
        'label' => esc_html__( 'Player Top Padding', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 550,
				'step' => 1,
				'default' => 30,
      ]
    );

    $this->add_control(
      'historyBottomPadding',
      [
        'label' => esc_html__( 'Player Bottom Padding', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 550,
				'step' => 1,
				'default' => 30,
      ]
    );

    $this->add_control(
      'centerPlayer',
      [
        'label' => esc_html__( 'Center Player', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-clever' ),
        'label_off' => esc_html__( 'No', 'elementor-clever' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );

    $this->add_control(
      'stickyx',
      [
        'label' => esc_html__( 'Sticky', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-clever' ),
        'label_off' => esc_html__( 'No', 'elementor-clever' ),
        'return_value' => 'true',
        'default' => 'false',
      ]
    );

    $this->add_control(
			'autoPlay',
			[
				'label' => esc_html__( 'Auto Play', 'elementor-clever' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-clever' ),
				'label_off' => esc_html__( 'No', 'elementor-clever' ),
				'return_value' => 'true',
				'default' => 'true',
			]
		);

    $this->add_control(
		'noImageAvailable',
		[
			'label' => esc_html__( 'Default "No Image Available"', 'elementor-clever' ),
			'type' => \Elementor\Controls_Manager::MEDIA,
			'default' => [
				'url' => \Elementor\Utils::get_placeholder_image_src(),
			]
		]
	  );

    $this->add_control(
      'grabLastFmPhoto',
      [
        'label' => esc_html__( 'Grab Artist Photo', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Yes', 'elementor-clever' ),
        'label_off' => esc_html__( 'No', 'elementor-clever' ),
        'return_value' => 'true',
        'default' => 'true',
      ]
    );

    $this->add_control(
      'borderWidth',
      [
        'label' => esc_html__( 'Player Border Width', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 550,
				'step' => 1,
				'default' => 1,
      ]
    );

    $this->add_control(
      'borderColor',
      [
        'label' => esc_html__( 'Player Border Color', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#bfbfbf',
      ]
    );

    $this->add_control(
      'bgColor',
      [
        'label' => esc_html__( 'Player Background Color', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#ffffff',
      ]
    );

    $this->add_control(
      'bgColorOpacity',
      [
        'label' => esc_html__( 'Player Background Color Alpha', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
				'min' => 0,
				'max' => 100,
				'step' => 10,
				'default' => 100,
      ]
    );

    $this->add_control(
      'numberOfElementsDisplayed',
      [
        'label' => esc_html__( 'Total Number Of Elements Displayed', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 100,
        'step' => 1,
        'default' => 6,
        'description' => esc_html__( 'including the current playing one', 'elementor-clever' ),
      ]
    );

    $this->add_control(
      'nowPlayingInterval',
      [
        'label' => esc_html__( 'Refresh Interval for Now-Playing Info', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 30,
        'max' => 100000,
        'step' => 5,
        'default' => 35,
      ]
    );

    $this->add_control(
      'delay',
      [
        'label' => esc_html__( 'Player Loading Delay', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 60,
        'step' => 1,
        'default' => 1,
      ]
    );

    $this->add_control(
      'barsColor',
      [
        'label' => esc_html__( 'Animated Bars Color', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#ffffff',
      ]
    );

    $this->add_control(
      'playButtonColor',
      [
        'label' => esc_html__( 'Play Button Color OFF State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#ffffff',
      ]
    );

    $this->add_control(
      'playButtonHoverColor',
      [
        'label' => esc_html__( 'Play Button Color ON State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#d7d7d7',
      ]
    );
    $this->add_control(
      'optional_images_path',
      [
        'label' => esc_html__( 'Path to the artist images/album covers folder', 'elementor-clever' ),
        'type' => Controls_Manager::TEXT,
        'label_block' => true,
        'default' => '',
      ]
    );


    $this->end_controls_section();

    /*history controls*/
    $this->start_controls_section(
      'history_content',
      [
        'label' => esc_html__( 'History Settings', 'elementor-clever' ),
      ]
    );

    $this->add_control(
			'useRadioServerTime',
			[
				'label' => esc_html__( 'Use Radio Server Time', 'elementor-clever' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Yes', 'elementor-clever' ),
				'label_off' => esc_html__( 'No', 'elementor-clever' ),
				'return_value' => 'true',
				'default' => 'false',
			]
		);

    $this->add_control(
      'historyRecordTimeOffColor',
      [
        'label' => esc_html__( 'History Record Time Color OFF State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#000000',
      ]
    );

    $this->add_control(
      'historyRecordSongOffColor',
      [
        'label' => esc_html__( 'History Record Song Color OFF State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#000000',
      ]
    );

    $this->add_control(
      'historyRecordAuthorOffColor',
      [
        'label' => esc_html__( 'History Record Author Color OFF State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#575757',
      ]
    );

    $this->add_control(
      'songAuthorLineSeparatorOffColor',
      [
        'label' => esc_html__( 'Line Separator Color OFF State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'default' => '#bfbfbf',
        'description' => esc_html__( 'between Song Title & Song Author', 'elementor-clever' ),
      ]
    );

    $this->add_control(
      'historyRecordBackgroundOnColor',
      [
        'label' => esc_html__( 'History Record Background Color ON State', 'elementor-clever' ),
        'label_block' => true,
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'default' => '#dd0060',
      ]
    );

    $this->add_control(
      'historyRecordTimeOnColor',
      [
        'label' => esc_html__( 'History Record Time Color ON State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#FFFFFF',
      ]
    );

    $this->add_control(
      'historyRecordSongOnColor',
      [
        'label' => esc_html__( 'History Record Song Color ON State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#FFFFFF',
      ]
    );

    $this->add_control(
      'historyRecordAuthorOnColor',
      [
        'label' => esc_html__( 'History Record Author Color ON State', 'elementor-clever' ),
        'type' => \Elementor\Controls_Manager::COLOR,
        'scheme' => [
          'type' => \Elementor\Core\Schemes\Color::get_type(),
          'value' => \Elementor\Core\Schemes\Color::COLOR_1,
        ],
        'alpha' => false,
        'default' => '#FFFFFF',
      ]
    );

    $this->end_controls_section();
  }

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function render() {
    $pathToAjaxFiles_aux=substr(plugin_dir_url(__FILE__),0,strlen(plugin_dir_url(__FILE__))-8).'audio11_html5_radio_history/';
    $rand_id=rand(10,999999);
    $settings = $this->get_settings_for_display();
    ?>
    <script>
  		jQuery(function() {
          setTimeout(function(){
          			jQuery("#lbg_audio11_html5_shoutcast_<?php echo $rand_id; ?>").audio11_html5({
                  radio_stream:"<?php echo $settings['radio_stream']; ?>",
                  optional_shoutcast_sid:<?php echo $settings['optional_shoutcast_sid']; ?>,
                  playerWidth:<?php echo $settings['playerWidth']; ?>,
                  width100Proc:<?php echo (($settings['width100Proc']==='true')?'true':'false'); ?>,
                  sticky:<?php echo (($settings['stickyx']==='true')?'true':'false'); ?>,
                  centerPlayer:<?php echo (($settings['centerPlayer']==='true')?'true':'false'); ?>,
                  grabLastFmPhoto:<?php echo (($settings['grabLastFmPhoto']==='true')?'true':'false'); ?>,
                  autoPlay:<?php echo (($settings['autoPlay']==='true')?'true':'false'); ?>,
                  borderWidth:<?php echo $settings['borderWidth']; ?>,
                  borderColor:"<?php echo $settings['borderColor']; ?>",
                  bgColor:"<?php echo $settings['bgColor']; ?>",
                  bgColorOpacity:<?php echo $settings['bgColorOpacity']; ?>,
                  barsColor:"<?php echo $settings['barsColor']; ?>",
                  playButtonColor:"<?php echo $settings['playButtonColor']; ?>",
                  playButtonHoverColor:"<?php echo $settings['playButtonHoverColor']; ?>",
                  numberOfElementsDisplayed:<?php echo $settings['numberOfElementsDisplayed']; ?>,
                  useRadioServerTime:<?php echo (($settings['useRadioServerTime']==='true')?'true':'false'); ?>,
                  optional_images_path:"<?php echo $settings['optional_images_path']; ?>",
                  historyLeftPadding:<?php echo $settings['historyLeftPadding']; ?>,
                  historyRightPadding:<?php echo $settings['historyRightPadding']; ?>,
                  historyTopPadding:<?php echo $settings['historyTopPadding']; ?>,
                  historyBottomPadding:<?php echo $settings['historyBottomPadding']; ?>,
                  songAuthorLineSeparatorOffColor:"<?php echo $settings['songAuthorLineSeparatorOffColor']; ?>",
                  historyRecordTimeOffColor:"<?php echo $settings['historyRecordTimeOffColor']; ?>",
                  historyRecordSongOffColor:"<?php echo $settings['historyRecordSongOffColor']; ?>",
                  historyRecordAuthorOffColor:"<?php echo $settings['historyRecordAuthorOffColor']; ?>",
                  historyRecordTimeOnColor:"<?php echo $settings['historyRecordTimeOnColor']; ?>",
                  historyRecordSongOnColor:"<?php echo $settings['historyRecordSongOnColor']; ?>",
                  historyRecordAuthorOnColor:"<?php echo $settings['historyRecordAuthorOnColor']; ?>",
                  historyRecordBackgroundOnColor:"<?php echo $settings['historyRecordBackgroundOnColor']; ?>",
                  pathToAjaxFiles:"<?php echo $pathToAjaxFiles_aux; ?>",
                  nowPlayingInterval:<?php echo $settings['nowPlayingInterval']; ?>,
                  noImageAvailable:"<?php echo $settings['noImageAvailable']['url']; ?>"
                });
          },<?php echo $settings['delay']*1000; ?>);
  		});
  	</script>
    <div class="audio11_html5">
            <div id="lbg_audio11_html5_shoutcast_<?php echo $rand_id; ?>"></div>
     </div>
    <?php
  }

  /**
   * Render the widget output in the editor.
   *
   * Written as a Backbone JavaScript template and used to generate the live preview.
   *
   * @since 1.1.0
   *
   * @access protected
   */
  protected function content_template() {

  }
}
